package com.sd.business.service.artwork.impl;

import cn.hutool.core.collection.CollUtil;
import com.ruoyi.common.utils.StringUtils;
import com.sd.business.entity.artwork.po.ArtworkLibrary;
import com.sd.business.mapper.artwork.ArtworkLibraryMapper;
import com.sd.business.service.artwork.ArtworkLibraryService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sd.business.entity.artwork.vo.ArtworkLibraryVo;
import com.sd.business.entity.artwork.dto.ArtworkLibrarySelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.sd.business.entity.artwork.dto.ArtworkLibraryDto;
import cn.hutool.core.bean.BeanUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 图稿库 服务实现类
 * </p>
 *
 * @author dk
 * @since 2023-08-01
 */
@Service
public class ArtworkLibraryServiceImpl extends ServiceImpl<ArtworkLibraryMapper, ArtworkLibrary> implements ArtworkLibraryService {

    @Override
    public List<ArtworkLibraryVo> getList(ArtworkLibrarySelectDto dto) {
        IWrapper<ArtworkLibrary> wrapper = getWrapper();
        wrapper.orderByDesc("al", ArtworkLibrary::getId);
        List<ArtworkLibraryVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<ArtworkLibraryVo> getPage(ArtworkLibrarySelectDto dto) {
        IWrapper<ArtworkLibrary> wrapper = getWrapper();
        wrapper.orderByDesc("al", ArtworkLibrary::getId);
        Page<ArtworkLibraryVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    /**
     * 删除图稿
     *
     * @param id
     * @return
     */
    @Override
    public ArtworkLibraryVo detail(Long id) {
        ArtworkLibrary ArtworkLibrary = this.getById(id);
        ArtworkLibraryVo result = BeanUtil.toBean(ArtworkLibrary, ArtworkLibraryVo.class);
        return result;
    }

    /**
     * 新增图稿
     *
     * @param artworkLibraryDto
     */
    @Override
    public void add(List<ArtworkLibraryDto> artworkLibraryDto) {
        ArrayList<ArtworkLibrary> artworkList = new ArrayList<>();
        for (ArtworkLibraryDto dto : artworkLibraryDto) {
            ArtworkLibrary artworkLibrary = new ArtworkLibrary();
            if (StringUtils.containsAny(dto.getArtworkUploadUrl(), ".ez3")) {
                artworkLibrary.setArtworkName(dto.getArtworkName());
                artworkLibrary.setArtworkUploadUrl(dto.getArtworkUploadUrl());
                artworkLibrary.setId(dto.getArtworkId());
                artworkLibrary.setArtworkTepy(1L);
            } else {
                artworkLibrary.setArtworkName(dto.getArtworkName());
                artworkLibrary.setArtworkUploadUrl(dto.getArtworkUploadUrl());
                artworkLibrary.setId(dto.getArtworkId());
                artworkLibrary.setArtworkTepy(0L);
            }
            artworkList.add(artworkLibrary);
        }
        this.saveBatch(artworkList);
    }

    /**
     * 修改图稿
     *
     * @param artworkLibraryDto
     */
    @Override
    public void edit(List<ArtworkLibraryDto> artworkLibraryDto) {
        ArrayList<ArtworkLibrary> artworkList = new ArrayList<>();
        for (ArtworkLibraryDto dto : artworkLibraryDto) {
            ArtworkLibrary artworkLibrary = new ArtworkLibrary();
            artworkLibrary.setArtworkName(dto.getArtworkName());
            artworkLibrary.setArtworkUploadUrl(dto.getArtworkUploadUrl());
            artworkLibrary.setId(dto.getArtworkId());
            artworkList.add(artworkLibrary);
        }
        this.updateBatchById(artworkList);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
